/*
 *  anthyaddwordpane.h
 *  Copyright(C) 2003- Masahito Omote <omote@utyuuzin.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __ANTHY_ADDWORDPANE_H__
#define __ANTHY_ADDWORDPANE_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif /* HAVE_CONFIG_H */

typedef struct _anthy_addwordpane {
    GtkWidget *pane;

    GtkWidget *phon;
    GtkWidget *desc;
    GtkWidget *optmenu_cclass_code;
    GtkWidget *cclass_code;
    GtkWidget *freq;

    GtkWidget *add;
    GtkWidget *clear;
} AnthyAddWordPane;

AnthyAddWordPane *anthy_addwordpane_new(void);
int show_addwordpane(AnthyAddWordPane *);

#endif /* __ANTHY_ADDWORDPANE_H__ */
